@@ -7,4 +7,7 @@ from .nrOFDMModulate import nrOFDMModulate
 from .nrOFDMDemodulate import nrOFDMDemodulate
 from .nrSSSIndices import nrSSSIndices
 from .nrExtractResources import nrExtractResources
-from .nrPSSIndices import nrPSSIndices
\ No newline at end of file
+from .nrPSSIndices import nrPSSIndices
+from .nrTimingEstimate import nrTimingEstimate
+from .nrPBCHDMRSIndices import nrPBCHDMRSIndices
+from .nrSetResources import nrSetResources
\ No newline at end of file
